==> apache-empire-db-2.5.1-dist.zip: apache-empire-db-2.5.1/src/empire-db/src/main/java/org/apache/empire/exceptions/InvalidArgumentException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.empire.exceptions;

import org.apache.empire.commons.ErrorType;
import org.apache.empire.commons.StringUtils;

public class InvalidArgumentException extends EmpireException
{
    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = 1L;
    
    public static final ErrorType errorType = new ErrorType("error.invalidArgument", "Invalid Argument {0} for parameter {1}.");
    
    public InvalidArgumentException(String param, Object value)
    {
        super(errorType, new String[] { StringUtils.valueOf(value), param } );
    }
    
    public InvalidArgumentException(String param, Object[] value)
    {
        super(errorType, new String[] { StringUtils.valueOf(value), param } );
    }

}

==> apache-empire-db-3.4.0-dist.zip: apache-empire-db-3.4.0/src/empire-db/src/main/java/org/apache/empire/exceptions/InvalidArgumentException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.empire.exceptions;

import org.apache.empire.commons.ErrorType;
import org.apache.empire.commons.StringUtils;

public class InvalidArgumentException extends EmpireException
{
    private static final long serialVersionUID = 1L;
    
    public static final ErrorType errorType = new ErrorType("error.invalidArgument", "Invalid Argument {0} for parameter {1}.");
    
    protected InvalidArgumentException(ErrorType errorType, String[] params)
    {
        super(errorType, params);
    }
    
    public InvalidArgumentException(String param, Object value)
    {
        super(errorType, new String[] { StringUtils.valueOf(value), param } );
    }
    
    public InvalidArgumentException(String param, Object[] value)
    {
        super(errorType, new String[] { StringUtils.valueOf(value), param } );
    }

}
